# BacDive Utils

Taxonomy managing tools.

## Workflow

### 0. Configuration

Edit the `config.yaml` file, and set the following variables:

* `BACDIVE_USER`: username for the BacDive API
* `BACDIVE_PASSWORD_FILE`: file containing the password for the BacDive API
* `ALVISNLP`: path to the AlvisNLP binary
* `REWRITE_TAXONOMY`: path to the `rewrite-taxonomy` binary


### 1. NCBI Taxonomy download

```shell
snakemake -j 1 -s ncbi-download.snakefile
```

**ETA: 2 minutes**

This will download the Taxonomy archive from the NCBI FTP server, then unzip the archive.

The download is anonymous and does not require any registration.

### 2. DSMZ catalog download

```shell
snakemake -j 1 -s dsmz-download.snakefile
```

**ETA: 10 hours**

This will download the whole DSMZ catalog via the BacDive service.

In order to use the BacDive API, you must [register](https://bacdive.dsmz.de/api/bacdive/registration/register/).
You must type the registered user to the variable `BACDIVE_USER` in the `config.yaml` file.
You also must record the password in a file (do not forget to remove read rights from group and others), then type the file path to the variable `BACDIVE_PASSWORD_FILE`.

### 3. Match DSMZ strains to NCBI taxonomy

```shell
snakemake -j 1 -s dsmz-match.snakefile
```

**ETA: 2 minutes**

This will look for a suitable place in the NCBI Taxonomy for each DMSZ strain.

The output of this step contains 5 files:
* `bacdive-to-taxid.txt`: a mapping file from the BacDive identifier of the strain to the taxon identifier
* `dispatch-report.txt`: a report of the dispatch for each DSMZ strain
* `dsmz-nodes.dmp` and `dsmz-names.dmp`: files in the format of the NCBI Taxonomy with additional nodes and synonyms
* `warnings.txt`: things to pay attention


### 4. Rewrite taxonomy

```shell
snakemake -j 1 -s rewrite-taxonomy.snakefile
```

**ETA: 12 minutes**

This will write the merged taxonomy in a format suitable for text projection.

## Resulting taxonomy

### Namespace prefixes

| Prefix | Domain | URL construct |
|--------|--------|---------------|
| `ncbi` | NCBI Taxonomy | `https://www.ncbi.nlm.nih.gov/Taxonomy/Browser/wwwtax.cgi?mode=Info&id={ID}` |
| | | `https://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi?db=taxonomy&id={ID}` |
| `bd`   | BacDive | `https://bacdive.dsmz.de/strain/{ID} |
| | | `https://api.bacdive.dsmz.de/example/fetch/{ID}` (authentication required) |
